==> download-2024.6.21_10.0.53-root-(ip-172-26-12-46).tar.gz: sistema/storage/framework/views/e36b103d425bd5645060f7d0d54b44b091e14072.php <==
<?php $__env->startSection('content'); ?>
 <!-- content -->

 <style>
    .color-azul {
    color: var(--azul) !important;
}

    .seccion-filtro {
    color: var(--gris-2);
    font-size: 14px;
    font-weight: 300;
}

.separador {
    margin: 0 0 20px 0;
    background-color: #adb0b3;
}
.cantidad-solicitud {
    color: var(--cobre);
    font-size: 3em;
    line-height: 50px;
    font-weight: 300;
    margin-bottom: 0.75rem;
}
.estado {
    box-shadow: 0 0.5rem 1rem rgba(0, 0, 0, 0.15) !important;
}

.estado:hover {
    box-shadow: 0 0.5rem 1rem rgba(16, 8, 162, 0.276) !important;
    transform: scale(1.05, 1.05);
    transition: 0.3s;
}
 </style>
<div class="titulos"> 
    <h2>Informes</h2>
    <hr />

</div>


 <div class="container-fluid botones-extremo " >
    <div class="d-flex justify-content-between">
        
       
    </div>
</div>

 <div class="row">
    <?php
                                

    $getDataUser = \App\Models\User::datosdelusaurioSeparados();
    // echo $getDataUser[0]->nombre;
    $nombre =base64_encode($getDataUser[0]->nombre);
    $apellido = base64_encode($getDataUser[0]->apellido);
    $nebio1 = base64_encode("nebio1"); 
    $getSucursal =\App\Models\User::nameBranchId($getDataUser[0]->sucursales_id);
    $sucursal = base64_encode($getSucursal);
    ?>

    <div class="row mb-2">

        <div class="col-sm-4" style="text-align: center">
            <div class="card estado revisar_pendientes" data-toggle="modal" data-target="#aPendientes">
                <div class="card-body border-lg rounded-3">
                    <div class="seccion-filtro color-azul" style="text-align: center">CAJA DIARIA</div>
                    <hr class="separador"> 
                    
                     
                        <?php 
                        $fecha_actual = date('Y-m-d');
                                // Codificar la fecha actual en Base64
                                $fxd = base64_encode($fecha_actual);
                        ?>
                    <a target="_blank" href="https://nebiolo.cl/informes/cajadiaria?fxr=<?php echo $fxd; ?>">
                        <img class="cantidad-solicitud d-inline" src="<?php echo e(asset('img/iconos/informe-pagos.png')); ?>" alt="" width="110px">
                    </a>

                </div>
            </div>
        </div>

        <div class="col-sm-4" style="text-align: center">
            <div class="card estado revisar_pendientes" data-toggle="modal" data-target="#aPendientes">
                <div class="card-body border-lg rounded-3">
                    <div class="seccion-filtro color-azul" style="text-align: center">GASTOS</div>
                    <hr class="separador"> 
                    <a  target="_blank"   href="https://iretail.cl/gastos/informes/?cl=bmViaW8x&n=QWx2YXJv&a=TmViaW9sbw=="   ><img lass="cantidad-solicitud d-inline" src="<?php echo e(asset('img/iconos/home512.png')); ?>" alt="" width="110px"></a>
                     
                </div>
            </div>
        </div>

        <div class="col-sm-4" style="text-align: center">
            <div class="card estado revisar_pendientes" data-toggle="modal" data-target="#aPendientes">
                <div class="card-body border-lg rounded-3">
                    <div class="seccion-filtro color-azul" style="text-align: center">DTE</div>
                    <hr class="separador">

                    <!-- <h5 class="cantidad-solicitud d-inline">0 -->
                        <a  target="_blank"  href="https://iretail.cl/emision_dte/facturacion/control_dte/pages/?c=cnBvc2NsX25lYmlvMQ==">
                        <img lass="cantidad-solicitud d-inline" src="<?php echo e(asset('img/iconos/dte.png')); ?>" alt="" width="110px">
                    
                        </a>
                        
                    <!-- </h5> -->

                    
                    <!-- <a class="btn btn-ter d-block mx-auto mt-4 revisar_pendientes" ><br></a> -->
                </div>
            </div>
        </div>

    
    </div>
      

            <div style="display: " class="row">

                <div class="col-sm-4" style="text-align: center">
                    <div class="card estado revisar_pendientes" data-toggle="modal" data-target="#aPendientes">
                        <div class="card-body border-lg rounded-3">
                            <div class="seccion-filtro color-azul" style="text-align: center">PAGOS</div>
                            <hr class="separador"> 
                            <a  target="_blank"    href="https://nebiolo.cl/informes/informedepagos?fxr=<?php echo $fxd; ?>" ><img lass="cantidad-solicitud d-inline" src="<?php echo e(asset('/img/iconos/pay.png')); ?>" alt="" width="110px"></a>
                             
                        </div>
                    </div>
                </div>

                <div class="col-sm-4" style="text-align: center ;display: none">
                    <div class="card estado revisar_pendientes" data-toggle="modal" data-target="#aPendientes">
                        <div class="card-body border-lg rounded-3">
                            <div class="seccion-filtro color-azul" style="text-align: center">ORDENES DE TRABAJO</div>
                            <hr class="separador"> 
                            <a href="<?php echo e(route('ordendetrabajo')); ?>"  ><img lass="cantidad-solicitud d-inline" src="<?php echo e(asset('/img/iconos/ot2.png')); ?>" alt="" width="110px"></a>
                             
                        </div>
                    </div>
                </div>

                <div class="col-sm-4" style="text-align: center ; display: none">
                    <div class="card estado revisar_pendientes" data-toggle="modal" data-target="#aPendientes">
                        <div class="card-body border-lg rounded-3">
                            <div class="seccion-filtro color-azul" style="text-align: center">NUEVA OT</div>
                            <hr class="separador">

                            <!-- <h5 class="cantidad-solicitud d-inline">0 -->
                                <a  href="<?php echo e(route('ot.crearsincliente')); ?>">
                                <img lass="cantidad-solicitud d-inline" src="<?php echo e(asset('/img/iconos/nuevaot.png')); ?>" alt="" width="110px">
                            
                                </a>
                                
                            <!-- </h5> -->

                            
                            <!-- <a class="btn btn-ter d-block mx-auto mt-4 revisar_pendientes" ><br></a> -->
                        </div>
                    </div>
                </div>

            
            </div>
        



</div>
<?php $__env->stopSection(); ?>

<?php echo $__env->make('layouts.sidebar', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?><?php /**PATH /var/www/html/sistema/resources/views/informes/homeinformes.blade.php ENDPATH**/ ?>

==> download-2024.9.2_10.5.12-root-(ip-172-26-12-46).tar.gz: sistema/storage/framework/views/e36b103d425bd5645060f7d0d54b44b091e14072.php <==
<?php $__env->startSection('content'); ?>
 <!-- content -->

 <style>
    .color-azul {
    color: var(--azul) !important;
}

    .seccion-filtro {
    color: var(--gris-2);
    font-size: 14px;
    font-weight: 300;
}

.separador {
    margin: 0 0 20px 0;
    background-color: #adb0b3;
}
.cantidad-solicitud {
    color: var(--cobre);
    font-size: 3em;
    line-height: 50px;
    font-weight: 300;
    margin-bottom: 0.75rem;
}
.estado {
    box-shadow: 0 0.5rem 1rem rgba(0, 0, 0, 0.15) !important;
}

.estado:hover {
    box-shadow: 0 0.5rem 1rem rgba(16, 8, 162, 0.276) !important;
    transform: scale(1.05, 1.05);
    transition: 0.3s;
}
 </style>
<div class="titulos"> 
    <h2>Informes</h2>
    <hr />

</div>


 <div class="container-fluid botones-extremo " >
    <div class="d-flex justify-content-between">
        
       
    </div>
</div>

 <div class="row">
    <?php
                                

    $getDataUser = \App\Models\User::datosdelusaurioSeparados();
    // echo $getDataUser[0]->nombre;
    $nombre =base64_encode($getDataUser[0]->nombre);
    $apellido = base64_encode($getDataUser[0]->apellido);
    $nebio1 = base64_encode("nebio1"); 
    $getSucursal =\App\Models\User::nameBranchId($getDataUser[0]->sucursales_id);
    $sucursal = base64_encode($getSucursal);
    ?>

    <div class="row mb-2">

        <div class="col-sm-4" style="text-align: center">
            <div class="card estado revisar_pendientes" data-toggle="modal" data-target="#aPendientes">
                <div class="card-body border-lg rounded-3">
                    <div class="seccion-filtro color-azul" style="text-align: center">CAJA DIARIA</div>
                    <hr class="separador"> 
                    
                     
                        <?php 
                        $fecha_actual = date('Y-m-d');
                                // Codificar la fecha actual en Base64
                                $fxd = base64_encode($fecha_actual);

                                // $urlCajaDiaria = "https://nebiolo.cl/informes/cajadiaria?fxr=".$fxd;
                        ?>
                    

                    
                    <a href="<?php echo e(route('gohomeiframe', ['url' => base64_encode("cajadiaria")])); ?>"  >
                        <img class="cantidad-solicitud d-inline" src="<?php echo e(asset('img/iconos/informe-pagos.png')); ?>" alt="" width="110px">
                    </a>


                </div>
            </div>
        </div>

        <div class="col-sm-4" style="text-align: center">
            <div class="card estado revisar_pendientes" data-toggle="modal" data-target="#aPendientes">
                <div class="card-body border-lg rounded-3">
                    <div class="seccion-filtro color-azul" style="text-align: center">GASTOS</div>
                    <hr class="separador"> 
                    
                    
                    <a href="<?php echo e(route('gohomeiframe', ['url' => base64_encode("gastos")])); ?>"  >
                        
                         <img lass="cantidad-solicitud d-inline" src="<?php echo e(asset('img/iconos/home512.png')); ?>" alt="" width="110px">
                    </a>
                     
                </div>
            </div>
        </div>

        <div class="col-sm-4" style="text-align: center">
            <div class="card estado revisar_pendientes" data-toggle="modal" data-target="#aPendientes">
                <div class="card-body border-lg rounded-3">
                    <div class="seccion-filtro color-azul" style="text-align: center">DTE</div>
                    <hr class="separador">

                    <!-- <h5 class="cantidad-solicitud d-inline">0 -->
                        
                    <a href="<?php echo e(route('gohomeiframe', ['url' => base64_encode("dte")])); ?>"  >
                        
                            <img lass="cantidad-solicitud d-inline" src="<?php echo e(asset('img/iconos/dte.png')); ?>" alt="" width="110px">

                    
                        </a>
                        
                    <!-- </h5> -->

                    
                    <!-- <a class="btn btn-ter d-block mx-auto mt-4 revisar_pendientes" ><br></a> -->
                </div>
            </div>
        </div>

    
    </div>
      

            <div style="display: " class="row">

                <div class="col-sm-4" style="text-align: center">
                    <div class="card estado revisar_pendientes" data-toggle="modal" data-target="#aPendientes">
                        <div class="card-body border-lg rounded-3">
                            <div class="seccion-filtro color-azul" style="text-align: center">PAGOS</div>
                            <hr class="separador"> 
                           
                           
                             
                   <a href="<?php echo e(route('gohomeiframe', ['url' => base64_encode("pagos")])); ?>"  > 

                                
                                <img lass="cantidad-solicitud d-inline" src="<?php echo e(asset('/img/iconos/pay.png')); ?>" alt="" width="110px">
                            
                            </a>
                             
                        </div>
                    </div>
                </div>

                <div class="col-sm-4" style="text-align: center ;display: none">
                    <div class="card estado revisar_pendientes" data-toggle="modal" data-target="#aPendientes">
                        <div class="card-body border-lg rounded-3">
                            <div class="seccion-filtro color-azul" style="text-align: center">ORDENES DE TRABAJO</div>
                            <hr class="separador"> 
                            <a href="<?php echo e(route('ordendetrabajo')); ?>"  ><img lass="cantidad-solicitud d-inline" src="<?php echo e(asset('/img/iconos/ot2.png')); ?>" alt="" width="110px"></a>
                             
                        </div>
                    </div>
                </div>

                <div class="col-sm-4" style="text-align: center ; display: none">
                    <div class="card estado revisar_pendientes" data-toggle="modal" data-target="#aPendientes">
                        <div class="card-body border-lg rounded-3">
                            <div class="seccion-filtro color-azul" style="text-align: center">NUEVA OT</div>
                            <hr class="separador">

                            <!-- <h5 class="cantidad-solicitud d-inline">0 -->
                                <a  href="<?php echo e(route('ot.crearsincliente')); ?>">
                                <img lass="cantidad-solicitud d-inline" src="<?php echo e(asset('/img/iconos/nuevaot.png')); ?>" alt="" width="110px">
                            
                                </a>
                                
                            <!-- </h5> -->

                            
                            <!-- <a class="btn btn-ter d-block mx-auto mt-4 revisar_pendientes" ><br></a> -->
                        </div>
                    </div>
                </div>

            
            </div>
        



</div>
<?php $__env->stopSection(); ?>

<?php echo $__env->make('layouts.sidebar', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?><?php /**PATH /var/www/html/sistema/resources/views/informes/homeinformes.blade.php ENDPATH**/ ?>
